@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 package Stenciller::Plugin::ToUnparsedText;
-our $VERSION = '0.1206'; # VERSION:
+our $VERSION = '0.1207'; # VERSION:
 # ABSTRACT: A plugin that doesn't transform the text
 
 use Moose;
@@ -14,14 +14,15 @@ sub transform {
     my $self = shift;
     my $transform_args = shift;
 
-    my @out = ('');
-    push (@out => $self->stenciller->all_header_lines, '') if !$transform_args->{'skip_header_lines'};
+    my @out = $self->init_out($self->stenciller, $transform_args);
 
     STENCIL:
-    for my $i (0 .. $self->stenciller->count_stencils - 1) {
-        next STENCIL if exists $transform_args->{'stencils'} && -1 == first_index { $_ == $i } @{ $transform_args->{'stencils'} };
+    for my $i (0 .. $self->stenciller->max_stencil_index) {
+        next STENCIL if $self->should_skip_stencil_by_index($i, $transform_args);
 
         my $stencil = $self->stenciller->get_stencil($i);
+        next STENCIL if $self->should_skip_stencil($stencil, $transform_args);
+
         push @out => '',
                      $stencil->all_before_input, '',
                      $stencil->all_input, '',
@@ -40,15 +41,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
-=head1 NAME
-
-Stenciller::Plugin::ToUnparsedText - A plugin that doesn't transform the text
-
-=head1 VERSION
-
-Version 0.1206, released 2015-02-07.
+:splint classname Stenciller::Plugin::ToUnparsedText
 
 =head1 SYNOPSIS
 
@@ -60,34 +53,6 @@ Version 0.1206, released 2015-02-07.
 
 This plugin to L<Stenciller> basically returns all text content of the stencils.
 
-
-
-=head1 METHODS
-
-
-=head2 transform
-
-=begin HTML
-
-<p></p>
-
-<!-- -->
-<table style="margin-bottom: 10px; margin-left: 10px; border-collapse: bollapse;" cellpadding="0" cellspacing="0">
-
-</table>
-
-=end HTML
-
-The currently available keys in the C<$transform_args> hash ref is:
-
-B<C<skip_header_lines =E<gt> 1>>
-
-C<skip_header_lines> takes a boolean indicating if the L<Stenciller's|Stenciller> header_lines should be skipped. Default is C<0>.
-
-B<C<stencils =E<gt> [ ]>>
-
-C<stencils> takes an array reference of which stencils in the currently parsed file that should be included in the output. The index is zero based.
-
 If this plugin is used via L<Pod::Elemental::Transformer::Stenciller> it could be used like this in pod:
 
     =pod
@@ -104,23 +69,11 @@ If this plugin is used via L<Pod::Elemental::Transformer::Stenciller> it could b
     # includes only the header_lines
     :stenciller ToUnparsedText atestfile-1.stencil { stencils => [] }
 
-=head1 SOURCE
+=head1 METHODS
 
-L<https://github.com/Csson/p5-Stenciller>
+=head2 transform
 
-=head1 HOMEPAGE
+See L<transform|Stenciller::Transformer/"transform"> in L<Stenciller::Transformer>.
 
-L<https://metacpan.org/release/Stenciller>
-
-=head1 AUTHOR
-
-Erik Carlsson <info@code301.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
 
 =cut
