@@ -2,7 +2,7 @@ use Stenciller::Standard;
 use Stenciller::Stencil;
 use strict;
 use warnings;
-our $VERSION = '0.1206'; # VERSION:
+our $VERSION = '0.1207'; # VERSION:
 # PODNAME: Stenciller::Wrap
 
 use Module::Pluggable search_path => ['Stenciller::Plugin'];
@@ -179,39 +179,8 @@ class Stenciller::Wrap using Moose with Stenciller::Utils {
             $self->add_stencil($clone);
         }
     }
+
+    method max_stencil_index {
+        return $self->count_stencils - 1;
+    }
 }
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Stenciller::Wrap
-
-=head1 VERSION
-
-Version 0.1206, released 2015-02-07.
-
-=head1 SOURCE
-
-L<https://github.com/Csson/p5-Stenciller>
-
-=head1 HOMEPAGE
-
-L<https://metacpan.org/release/Stenciller>
-
-=head1 AUTHOR
-
-Erik Carlsson <info@code301.com>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
